@@ -14,21 +14,26 @@ pub fn cd(path: &path::Path, context: &mut AppContext) -> std::io::Result<()> {
 
 pub fn change_directory(context: &mut AppContext, path: &path::Path) -> JoshutoResult {
     let new_cwd = if path.is_absolute() {
-        path.canonicalize()?
+        path.to_path_buf()
     } else {
         let mut new_cwd = std::env::current_dir()?;
-        new_cwd.push(path.canonicalize()?);
+        new_cwd.push(path);
         new_cwd
     };
 
     cd(new_cwd.as_path(), context)?;
     let options = context.config_ref().display_options_ref().clone();
     let ui_context = context.ui_context_ref().clone();
+    let tab_options = context
+        .tab_context_ref()
+        .curr_tab_ref()
+        .option_ref()
+        .clone();
     context
         .tab_context_mut()
         .curr_tab_mut()
         .history_mut()
-        .populate_to_root(new_cwd.as_path(), &ui_context, &options)?;
+        .populate_to_root(new_cwd.as_path(), &ui_context, &options, &tab_options)?;
     Ok(())
 }
 
@@ -46,7 +51,7 @@ pub fn parent_directory(context: &mut AppContext) -> JoshutoResult {
             .tab_context_mut()
             .curr_tab_mut()
             .set_cwd(parent.as_path());
-        reload::soft_reload(context.tab_context_ref().index, context)?;
+        reload::soft_reload_curr_tab(context)?;
     }
     Ok(())
 }
@@ -60,7 +65,7 @@ pub fn previous_directory(context: &mut AppContext) -> JoshutoResult {
             .tab_context_mut()
             .curr_tab_mut()
             .set_cwd(path.as_path());
-        reload::soft_reload(context.tab_context_ref().index, context)?;
+        reload::soft_reload_curr_tab(context)?;
     }
     Ok(())
 }
