@@ -4,7 +4,7 @@ use crate::config::AppKeyMapping;
 use crate::context::AppContext;
 use crate::error::JoshutoResult;
 use crate::key_command::{AppExecute, Command};
-use crate::ui::views::TuiTextField;
+use crate::ui::views::{DummyListener, TuiTextField};
 use crate::ui::AppBackend;
 
 pub fn read_and_execute(
@@ -15,11 +15,12 @@ pub fn read_and_execute(
     suffix: &str,
 ) -> JoshutoResult {
     context.flush_event();
+    let mut listener = DummyListener {};
     let user_input: Option<String> = TuiTextField::default()
         .prompt(":")
         .prefix(prefix)
         .suffix(suffix)
-        .get_input(backend, context);
+        .get_input(backend, context, &mut listener);
 
     if let Some(s) = user_input {
         let trimmed = s.trim_start();
