@@ -1,6 +1,6 @@
 use crate::context::AppContext;
 use crate::error::JoshutoResult;
-use crate::ui::TuiBackend;
+use crate::ui::AppBackend;
 
 pub fn lazy_load_directory_size(context: &mut AppContext) {
     let directory_size = match context
@@ -38,82 +38,89 @@ pub fn lazy_load_directory_size(context: &mut AppContext) {
     }
 }
 
-pub fn cursor_move(new_index: usize, context: &mut AppContext) {
+pub fn cursor_move(context: &mut AppContext, new_index: usize) {
     lazy_load_directory_size(context);
     let mut new_index = new_index;
+    let ui_context = context.ui_context_ref().clone();
+    let display_options = context.config_ref().display_options_ref().clone();
     if let Some(curr_list) = context.tab_context_mut().curr_tab_mut().curr_list_mut() {
         if !curr_list.is_empty() {
             let dir_len = curr_list.len();
             if new_index >= dir_len {
                 new_index = dir_len - 1;
             }
-            curr_list.index = Some(new_index);
+            curr_list.set_index(Some(new_index), &ui_context, &display_options);
         }
     }
 }
 
-pub fn up(context: &mut AppContext, u: usize) -> JoshutoResult<()> {
-    let movement = match context.tab_context_ref().curr_tab_ref().curr_list_ref() {
-        Some(curr_list) => curr_list.index.map(|idx| if idx > u { idx - u } else { 0 }),
-        None => None,
-    };
+pub fn up(context: &mut AppContext, u: usize) -> JoshutoResult {
+    let movement = context
+        .tab_context_ref()
+        .curr_tab_ref()
+        .curr_list_ref()
+        .and_then(|list| list.get_index().map(|idx| idx.saturating_sub(u)));
 
     if let Some(s) = movement {
-        cursor_move(s, context);
+        cursor_move(context, s);
     }
     Ok(())
 }
 
-pub fn down(context: &mut AppContext, u: usize) -> JoshutoResult<()> {
-    let movement = match context.tab_context_ref().curr_tab_ref().curr_list_ref() {
-        Some(curr_list) => curr_list.index.map(|idx| idx + u),
-        None => None,
-    };
+pub fn down(context: &mut AppContext, u: usize) -> JoshutoResult {
+    let movement = context
+        .tab_context_ref()
+        .curr_tab_ref()
+        .curr_list_ref()
+        .and_then(|list| list.get_index().map(|idx| idx.saturating_add(u)));
+
     if let Some(s) = movement {
-        cursor_move(s, context);
+        cursor_move(context, s);
     }
     Ok(())
 }
 
-pub fn home(context: &mut AppContext) -> JoshutoResult<()> {
-    let movement: Option<usize> = match context.tab_context_ref().curr_tab_ref().curr_list_ref() {
-        Some(curr_list) => {
+pub fn home(context: &mut AppContext) -> JoshutoResult {
+    let movement = context
+        .tab_context_ref()
+        .curr_tab_ref()
+        .curr_list_ref()
+        .and_then(|curr_list| {
             let len = curr_list.len();
             if len == 0 {
                 None
             } else {
                 Some(0)
             }
-        }
-        None => None,
-    };
+        });
 
     if let Some(s) = movement {
-        cursor_move(s, context);
+        cursor_move(context, s);
     }
     Ok(())
 }
 
-pub fn end(context: &mut AppContext) -> JoshutoResult<()> {
-    let movement: Option<usize> = match context.tab_context_ref().curr_tab_ref().curr_list_ref() {
-        Some(curr_list) => {
+pub fn end(context: &mut AppContext) -> JoshutoResult {
+    let movement = context
+        .tab_context_ref()
+        .curr_tab_ref()
+        .curr_list_ref()
+        .and_then(|curr_list| {
             let len = curr_list.len();
             if len == 0 {
                 None
             } else {
                 Some(len - 1)
             }
-        }
-        None => None,
-    };
+        });
 
     if let Some(s) = movement {
-        cursor_move(s, context);
+        cursor_move(context, s);
     }
     Ok(())
 }
 
-fn get_page_size(context: &AppContext, backend: &TuiBackend) -> Option<usize> {
+fn get_page_size(context: &AppContext, backend: &AppBackend) -> Option<usize> {
     let config = context.config_ref();
     let rect = backend.terminal.as_ref().map(|t| t.size())?.ok()?;
 
@@ -124,50 +131,89 @@ fn get_page_size(context: &AppContext, backend: &TuiBackend) -> Option<usize> {
         } else {
             None
         }
+    } else if rect_height >= 2 {
+        Some(rect_height - 2)
     } else {
-        if rect_height >= 2 {
-            Some(rect_height - 2)
-        } else {
-            None
-        }
+        None
     }
 }
 
-pub fn page_up(context: &mut AppContext, backend: &mut TuiBackend) -> JoshutoResult<()> {
-    let page_size = get_page_size(context, backend).unwrap_or(10);
+pub fn page_up(
+    context: &mut AppContext,
+    backend: &mut AppBackend,
+    proportion: f64,
+) -> JoshutoResult {
+    let page_size = get_page_size(context, backend).unwrap_or(10) as f64 * proportion;
+    let page_size = page_size as usize;
 
-    let movement = match context.tab_context_ref().curr_tab_ref().curr_list_ref() {
-        Some(curr_list) => curr_list
-            .index
-            .map(|idx| if idx > page_size { idx - page_size } else { 0 }),
-        None => None,
-    };
+    let movement = context
+        .tab_context_ref()
+        .curr_tab_ref()
+        .curr_list_ref()
+        .and_then(|list| list.get_index().map(|idx| idx.saturating_sub(page_size)));
 
     if let Some(s) = movement {
-        cursor_move(s, context);
+        cursor_move(context, s);
     }
     Ok(())
 }
 
-pub fn page_down(context: &mut AppContext, backend: &mut TuiBackend) -> JoshutoResult<()> {
-    let page_size = get_page_size(context, backend).unwrap_or(10);
+pub fn page_down(
+    context: &mut AppContext,
+    backend: &mut AppBackend,
+    proportion: f64,
+) -> JoshutoResult {
+    let page_size = get_page_size(context, backend).unwrap_or(10) as f64 * proportion;
+    let page_size = page_size as usize;
 
-    let movement = match context.tab_context_ref().curr_tab_ref().curr_list_ref() {
-        Some(curr_list) => {
-            let dir_len = curr_list.len();
-            curr_list.index.map(|idx| {
-                if idx + page_size > dir_len - 1 {
-                    dir_len - 1
-                } else {
-                    idx + page_size
-                }
-            })
-        }
-        None => None,
-    };
+    let new_index = context
+        .tab_context_ref()
+        .curr_tab_ref()
+        .curr_list_ref()
+        .and_then(|list| list.get_index().map(|idx| idx.saturating_add(page_size)));
 
-    if let Some(s) = movement {
-        cursor_move(s, context);
+    if let Some(idx) = new_index {
+        cursor_move(context, idx);
+    }
+    Ok(())
+}
+
+pub fn page_home(context: &mut AppContext, _: &mut AppBackend) -> JoshutoResult {
+    let new_index = context
+        .tab_context_ref()
+        .curr_tab_ref()
+        .curr_list_ref()
+        .map(|curr_list| curr_list.first_index_for_viewport());
+    if let Some(idx) = new_index {
+        cursor_move(context, idx);
+    }
+    Ok(())
+}
+
+pub fn page_middle(context: &mut AppContext, backend: &mut AppBackend) -> JoshutoResult {
+    let movement = get_page_size(context, backend).unwrap_or(10) / 2;
+
+    let new_index = context
+        .tab_context_ref()
+        .curr_tab_ref()
+        .curr_list_ref()
+        .map(|curr_list| curr_list.first_index_for_viewport() + movement);
+    if let Some(idx) = new_index {
+        cursor_move(context, idx);
+    }
+    Ok(())
+}
+
+pub fn page_end(context: &mut AppContext, backend: &mut AppBackend) -> JoshutoResult {
+    let movement = get_page_size(context, backend).unwrap_or(10) - 1;
+
+    let new_index = context
+        .tab_context_ref()
+        .curr_tab_ref()
+        .curr_list_ref()
+        .map(|curr_list| curr_list.first_index_for_viewport() + movement);
+    if let Some(idx) = new_index {
+        cursor_move(context, idx);
     }
     Ok(())
 }
