@@ -1,11 +1,15 @@
+pub mod bookmark;
 pub mod bulk_rename;
 pub mod change_directory;
 pub mod command_line;
 pub mod cursor_move;
 pub mod delete_files;
+pub mod escape;
 pub mod file_ops;
+pub mod filter;
 pub mod flat;
 pub mod line_nums;
+pub mod linemode;
 pub mod new_directory;
 pub mod numbered_command;
 pub mod open_file;
@@ -18,7 +22,7 @@ pub mod search;
 pub mod search_fzf;
 pub mod search_glob;
 pub mod search_string;
-pub mod selection;
+pub mod select;
 pub mod set_mode;
 pub mod show_help;
 pub mod show_hidden;
@@ -28,4 +32,5 @@ pub mod sub_process;
 pub mod subdir_fzf;
 pub mod tab_ops;
 pub mod touch_file;
+pub mod uimodes;
 pub mod zoxide;
