@@ -17,7 +17,7 @@ pub fn search_next(context: &mut AppContext) -> JoshutoResult {
             }
         };
         if let Some(index) = index {
-            let _ = cursor_move::cursor_move(context, index);
+            cursor_move::cursor_move(context, index);
         }
     }
     Ok(())
@@ -34,7 +34,7 @@ pub fn search_prev(context: &mut AppContext) -> JoshutoResult {
             }
         };
         if let Some(index) = index {
-            let _ = cursor_move::cursor_move(context, index);
+            cursor_move::cursor_move(context, index);
         }
     }
     Ok(())
