@@ -1,4 +1,6 @@
 pub mod display_option;
+pub mod linemodes;
+pub mod new_tab_option;
 pub mod preview_option;
 pub mod select_option;
 pub mod sort_option;
@@ -6,6 +8,8 @@ pub mod sort_type;
 pub mod tab_option;
 
 pub use self::display_option::*;
+pub use self::linemodes::*;
+pub use self::new_tab_option::*;
 pub use self::preview_option::*;
 pub use self::select_option::*;
 pub use self::sort_option::*;
