@@ -3,16 +3,20 @@ use std::collections::HashMap;
 
 use super::DEFAULT_CONFIG_FILE_PATH;
 use super::{AppStyle, AppStyleRaw};
-use crate::config::{parse_to_config_file, TomlConfigFile};
+use crate::config::{parse_config_or_default, TomlConfigFile};
 use crate::error::JoshutoResult;
 
 #[derive(Clone, Debug, Deserialize, Default)]
 pub struct AppThemeRaw {
+    #[serde(default)]
+    pub tabs: TabThemeRaw,
     #[serde(default)]
     pub regular: AppStyleRaw,
     #[serde(default)]
     pub selection: AppStyleRaw,
     #[serde(default)]
+    pub visual_mode_selection: AppStyleRaw,
+    #[serde(default)]
     pub directory: AppStyleRaw,
     #[serde(default)]
     pub executable: AppStyleRaw,
@@ -26,9 +30,27 @@ pub struct AppThemeRaw {
     pub ext: HashMap<String, AppStyleRaw>,
 }
 
+#[derive(Clone, Debug, Deserialize, Default)]
+pub struct TabThemeRaw {
+    #[serde(default)]
+    pub inactive: AppStyleRaw,
+    #[serde(default)]
+    pub active: AppStyleRaw,
+}
+
+impl From<TabThemeRaw> for TabTheme {
+    fn from(crude: TabThemeRaw) -> Self {
+        let inactive = crude.inactive.to_style_theme();
+        let active = crude.active.to_style_theme();
+        Self { inactive, active }
+    }
+}
+
 impl From<AppThemeRaw> for AppTheme {
     fn from(crude: AppThemeRaw) -> Self {
+        let tabs = crude.tabs;
         let selection = crude.selection.to_style_theme();
+        let visual_mode_selection = crude.visual_mode_selection.to_style_theme();
         let executable = crude.executable.to_style_theme();
         let regular = crude.regular.to_style_theme();
         let directory = crude.directory.to_style_theme();
@@ -46,6 +68,7 @@ impl From<AppThemeRaw> for AppTheme {
 
         Self {
             selection,
+            visual_mode_selection,
             executable,
             regular,
             directory,
@@ -53,14 +76,17 @@ impl From<AppThemeRaw> for AppTheme {
             link_invalid,
             socket,
             ext,
+            tabs: TabTheme::from(tabs),
         }
     }
 }
 
 #[derive(Clone, Debug)]
 pub struct AppTheme {
+    pub tabs: TabTheme,
     pub regular: AppStyle,
     pub selection: AppStyle,
+    pub visual_mode_selection: AppStyle,
     pub directory: AppStyle,
     pub executable: AppStyle,
     pub link: AppStyle,
@@ -78,7 +104,7 @@ impl AppTheme {
 
 impl TomlConfigFile for AppTheme {
     fn get_config(file_name: &str) -> Self {
-        parse_to_config_file::<AppThemeRaw, AppTheme>(file_name).unwrap_or_default()
+        parse_config_or_default::<AppThemeRaw, AppTheme>(file_name)
     }
 }
 
@@ -89,3 +115,9 @@ impl std::default::Default for AppTheme {
         Self::default_res().unwrap()
     }
 }
+
+#[derive(Clone, Debug)]
+pub struct TabTheme {
+    pub inactive: AppStyle,
+    pub active: AppStyle,
+}
