@@ -4,6 +4,7 @@ mod local_state;
 mod message_queue;
 mod preview_context;
 mod tab_context;
+mod ui_context;
 mod worker_context;
 
 pub use self::app_context::*;
@@ -12,4 +13,5 @@ pub use self::local_state::*;
 pub use self::message_queue::*;
 pub use self::preview_context::*;
 pub use self::tab_context::*;
+pub use self::ui_context::*;
 pub use self::worker_context::*;
