@@ -24,7 +24,6 @@ cmd_constants![
     (CMD_CLOSE_TAB, "close_tab"),
     (CMD_CUT_FILES, "cut_files"),
     (CMD_COPY_FILES, "copy_files"),
-    (CMD_PASTE_FILES, "paste_files"),
     (CMD_COPY_FILENAME, "copy_filename"),
     (
         CMD_COPY_FILENAME_WITHOUT_EXTENSION,
@@ -32,6 +31,9 @@ cmd_constants![
     ),
     (CMD_COPY_FILEPATH, "copy_filepath"),
     (CMD_COPY_DIRECTORY_PATH, "copy_dirpath"),
+    (CMD_SYMLINK_FILES, "symlink_files"),
+    (CMD_PASTE_FILES, "paste_files"),
+    (CMD_DELETE_FILES, "delete_files"),
     (CMD_CURSOR_MOVE_UP, "cursor_move_up"),
     (CMD_CURSOR_MOVE_DOWN, "cursor_move_down"),
     (CMD_CURSOR_MOVE_HOME, "cursor_move_home"),
@@ -45,7 +47,6 @@ cmd_constants![
     (CMD_PARENT_CURSOR_MOVE_DOWN, "parent_cursor_move_down"),
     (CMD_PREVIEW_CURSOR_MOVE_UP, "preview_cursor_move_up"),
     (CMD_PREVIEW_CURSOR_MOVE_DOWN, "preview_cursor_move_down"),
-    (CMD_DELETE_FILES, "delete_files"),
     (CMD_NEW_DIRECTORY, "mkdir"),
     (CMD_OPEN_FILE, "open"),
     (CMD_OPEN_FILE_WITH, "open_with"),
@@ -53,6 +54,7 @@ cmd_constants![
     (CMD_RENAME_FILE, "rename"),
     (CMD_RENAME_FILE_APPEND, "rename_append"),
     (CMD_RENAME_FILE_PREPEND, "rename_prepend"),
+    (CMD_RENAME_FILE_KEEP_EXT, "rename_keep_ext"),
     (CMD_SEARCH_STRING, "search"),
     (CMD_SEARCH_INCREMENTAL, "search_inc"),
     (CMD_SEARCH_GLOB, "search_glob"),
@@ -68,14 +70,21 @@ cmd_constants![
     (CMD_TAB_SWITCH, "tab_switch"),
     (CMD_TAB_SWITCH_INDEX, "tab_switch_index"),
     (CMD_TOGGLE_HIDDEN, "toggle_hidden"),
+    (CMD_TOGGLE_VISUAL, "toggle_visual"),
     (CMD_SWITCH_LINE_NUMBERS, "line_nums"),
+    (CMD_SET_LINEMODE, "linemode"),
     (CMD_TOUCH_FILE, "touch"),
     (CMD_HELP, "help"),
     (CMD_SEARCH_FZF, "search_fzf"),
     (CMD_SUBDIR_FZF, "subdir_fzf"),
     (CMD_ZOXIDE, "z"),
     (CMD_ZOXIDE_INTERACTIVE, "zi"),
+    (CMD_NUMBERED_COMMAND, "numbered_command"),
     (CMD_FLAT, "flat"),
+    (CMD_ESCAPE, "escape"),
+    (CMD_FILTER, "filter"),
+    (CMD_BOOKMARK_ADD, "add_bookmark"),
+    (CMD_BOOKMARK_CHANGE_DIRECTORY, "cd_bookmark"),
 ];
 
 pub fn complete_command(partial_command: &str) -> Vec<Pair> {
