@@ -1,12 +1,10 @@
 use std::path;
 
-use dirs_next::home_dir;
-use shellexpand::tilde_with_context;
-
 use crate::commands::quit::QuitAction;
-use crate::config::option::{LineNumberStyle, SelectOption, SortType};
+use crate::config::option::{LineMode, LineNumberStyle, NewTabMode, SelectOption, SortType};
 use crate::error::{JoshutoError, JoshutoErrorKind};
-use crate::io::IoWorkerOptions;
+use crate::io::FileOperationOptions;
+use crate::util::unix;
 
 use crate::HOME_DIR;
 
@@ -26,7 +24,10 @@ impl std::str::FromStr for Command {
 
     fn from_str(s: &str) -> Result<Self, Self::Err> {
         if let Some(stripped) = s.strip_prefix(':') {
-            return Ok(Self::CommandLine(stripped.to_owned(), "".to_owned()));
+            return Ok(Self::CommandLine {
+                prefix: stripped.to_owned(),
+                suffix: "".to_owned(),
+            });
         }
 
         let (command, arg) = match s.find(' ') {
@@ -34,14 +35,23 @@ impl std::str::FromStr for Command {
             None => (s, ""),
         };
 
-        simple_command_conversion_case!(command, CMD_NEW_TAB, Self::NewTab);
+        simple_command_conversion_case!(command, CMD_ESCAPE, Self::Escape);
+
+        simple_command_conversion_case!(command, CMD_TOGGLE_VISUAL, Self::ToggleVisualMode);
+
         simple_command_conversion_case!(command, CMD_CLOSE_TAB, Self::CloseTab);
 
         simple_command_conversion_case!(command, CMD_HELP, Self::Help);
 
+        simple_command_conversion_case!(command, CMD_BOOKMARK_ADD, Self::BookmarkAdd);
+        simple_command_conversion_case!(
+            command,
+            CMD_BOOKMARK_CHANGE_DIRECTORY,
+            Self::BookmarkChangeDirectory
+        );
+
         simple_command_conversion_case!(command, CMD_CURSOR_MOVE_HOME, Self::CursorMoveHome);
         simple_command_conversion_case!(command, CMD_CURSOR_MOVE_END, Self::CursorMoveEnd);
-
         simple_command_conversion_case!(
             command,
             CMD_CURSOR_MOVE_PAGEHOME,
@@ -55,8 +65,6 @@ impl std::str::FromStr for Command {
         simple_command_conversion_case!(command, CMD_CURSOR_MOVE_PAGEEND, Self::CursorMovePageEnd);
 
         simple_command_conversion_case!(command, CMD_CUT_FILES, Self::CutFiles);
-        simple_command_conversion_case!(command, CMD_DELETE_FILES, Self::DeleteFiles);
-
         simple_command_conversion_case!(command, CMD_COPY_FILES, Self::CopyFiles);
         simple_command_conversion_case!(command, CMD_COPY_FILENAME, Self::CopyFileName);
         simple_command_conversion_case!(
@@ -72,6 +80,7 @@ impl std::str::FromStr for Command {
         simple_command_conversion_case!(command, CMD_RELOAD_DIRECTORY_LIST, Self::ReloadDirList);
         simple_command_conversion_case!(command, CMD_RENAME_FILE_APPEND, Self::RenameFileAppend);
         simple_command_conversion_case!(command, CMD_RENAME_FILE_PREPEND, Self::RenameFilePrepend);
+        simple_command_conversion_case!(command, CMD_RENAME_FILE_KEEP_EXT, Self::RenameFileKeepExt);
         simple_command_conversion_case!(command, CMD_SEARCH_NEXT, Self::SearchNext);
         simple_command_conversion_case!(command, CMD_SEARCH_PREV, Self::SearchPrev);
         simple_command_conversion_case!(command, CMD_SHOW_TASKS, Self::ShowTasks);
@@ -91,10 +100,14 @@ impl std::str::FromStr for Command {
                 "--output-selected-files" => Ok(Self::Quit(QuitAction::OutputSelectedFiles)),
                 _ => Ok(Self::Quit(QuitAction::Noop)),
             }
+        } else if command == CMD_NEW_TAB {
+            Ok(Self::NewTab {
+                mode: NewTabMode::from_str(arg),
+            })
         } else if command == CMD_CHANGE_DIRECTORY {
             match arg {
                 "" => match HOME_DIR.as_ref() {
-                    Some(s) => Ok(Self::ChangeDirectory(s.clone())),
+                    Some(s) => Ok(Self::ChangeDirectory { path: s.clone() }),
                     None => Err(JoshutoError::new(
                         JoshutoErrorKind::EnvVarNotPresent,
                         format!("{}: Cannot find home directory", command),
@@ -102,16 +115,16 @@ impl std::str::FromStr for Command {
                 },
                 ".." => Ok(Self::ParentDirectory),
                 "-" => Ok(Self::PreviousDirectory),
-                arg => Ok({
-                    let path_accepts_tilde = tilde_with_context(arg, home_dir);
-                    Self::ChangeDirectory(path::PathBuf::from(path_accepts_tilde.as_ref()))
-                }),
+                arg => {
+                    let new_path = unix::expand_shell_string(arg);
+                    Ok(Self::ChangeDirectory { path: new_path })
+                }
             }
         } else if command == CMD_CURSOR_MOVE_DOWN {
             match arg {
-                "" => Ok(Self::CursorMoveDown(1)),
+                "" => Ok(Self::CursorMoveDown { offset: 1 }),
                 arg => match arg.trim().parse::<usize>() {
-                    Ok(s) => Ok(Self::CursorMoveDown(s)),
+                    Ok(s) => Ok(Self::CursorMoveDown { offset: s }),
                     Err(e) => Err(JoshutoError::new(
                         JoshutoErrorKind::ParseError,
                         e.to_string(),
@@ -126,9 +139,9 @@ impl std::str::FromStr for Command {
             Ok(Self::CursorMovePageDown(p))
         } else if command == CMD_CURSOR_MOVE_UP {
             match arg {
-                "" => Ok(Self::CursorMoveUp(1)),
+                "" => Ok(Self::CursorMoveUp { offset: 1 }),
                 arg => match arg.trim().parse::<usize>() {
-                    Ok(s) => Ok(Self::CursorMoveUp(s)),
+                    Ok(s) => Ok(Self::CursorMoveUp { offset: s }),
                     Err(e) => Err(JoshutoError::new(
                         JoshutoErrorKind::ParseError,
                         e.to_string(),
@@ -137,9 +150,9 @@ impl std::str::FromStr for Command {
             }
         } else if command == CMD_PARENT_CURSOR_MOVE_DOWN {
             match arg {
-                "" => Ok(Self::ParentCursorMoveDown(1)),
+                "" => Ok(Self::ParentCursorMoveDown { offset: 1 }),
                 arg => match arg.trim().parse::<usize>() {
-                    Ok(s) => Ok(Self::ParentCursorMoveDown(s)),
+                    Ok(s) => Ok(Self::ParentCursorMoveDown { offset: s }),
                     Err(e) => Err(JoshutoError::new(
                         JoshutoErrorKind::ParseError,
                         e.to_string(),
@@ -148,9 +161,9 @@ impl std::str::FromStr for Command {
             }
         } else if command == CMD_PARENT_CURSOR_MOVE_UP {
             match arg {
-                "" => Ok(Self::ParentCursorMoveUp(1)),
+                "" => Ok(Self::ParentCursorMoveUp { offset: 1 }),
                 arg => match arg.trim().parse::<usize>() {
-                    Ok(s) => Ok(Self::ParentCursorMoveUp(s)),
+                    Ok(s) => Ok(Self::ParentCursorMoveUp { offset: s }),
                     Err(e) => Err(JoshutoError::new(
                         JoshutoErrorKind::ParseError,
                         e.to_string(),
@@ -159,9 +172,9 @@ impl std::str::FromStr for Command {
             }
         } else if command == CMD_PREVIEW_CURSOR_MOVE_DOWN {
             match arg {
-                "" => Ok(Self::PreviewCursorMoveDown(1)),
+                "" => Ok(Self::PreviewCursorMoveDown { offset: 1 }),
                 arg => match arg.trim().parse::<usize>() {
-                    Ok(s) => Ok(Self::PreviewCursorMoveDown(s)),
+                    Ok(s) => Ok(Self::PreviewCursorMoveDown { offset: s }),
                     Err(e) => Err(JoshutoError::new(
                         JoshutoErrorKind::ParseError,
                         e.to_string(),
@@ -170,9 +183,9 @@ impl std::str::FromStr for Command {
             }
         } else if command == CMD_PREVIEW_CURSOR_MOVE_UP {
             match arg {
-                "" => Ok(Self::PreviewCursorMoveUp(1)),
+                "" => Ok(Self::PreviewCursorMoveUp { offset: 1 }),
                 arg => match arg.trim().parse::<usize>() {
-                    Ok(s) => Ok(Self::PreviewCursorMoveUp(s)),
+                    Ok(s) => Ok(Self::PreviewCursorMoveUp { offset: s }),
                     Err(e) => Err(JoshutoError::new(
                         JoshutoErrorKind::ParseError,
                         e.to_string(),
@@ -186,21 +199,37 @@ impl std::str::FromStr for Command {
                     format!("{}: no directory name given", command),
                 ))
             } else {
-                Ok(Self::NewDirectory(path::PathBuf::from(arg)))
+                let path = path::PathBuf::from(arg);
+                Ok(Self::NewDirectory { path })
             }
         } else if command == CMD_OPEN_FILE_WITH {
             match arg {
-                "" => Ok(Self::OpenFileWith(None)),
+                "" => Ok(Self::OpenFileWith { index: None }),
                 arg => match arg.trim().parse::<usize>() {
-                    Ok(s) => Ok(Self::OpenFileWith(Some(s))),
+                    Ok(s) => Ok(Self::OpenFileWith { index: Some(s) }),
                     Err(e) => Err(JoshutoError::new(
                         JoshutoErrorKind::ParseError,
                         e.to_string(),
                     )),
                 },
             }
+        } else if command == CMD_SYMLINK_FILES {
+            let mut relative = false;
+            for arg in arg.split_whitespace() {
+                match arg {
+                    "--relative=true" => relative = true,
+                    "--relative=false" => relative = false,
+                    _ => {
+                        return Err(JoshutoError::new(
+                            JoshutoErrorKind::UnrecognizedArgument,
+                            format!("{}: unknown option '{}'", command, arg),
+                        ));
+                    }
+                }
+            }
+            Ok(Self::SymlinkFiles { relative })
         } else if command == CMD_PASTE_FILES {
-            let mut options = IoWorkerOptions::default();
+            let mut options = FileOperationOptions::default();
             for arg in arg.split_whitespace() {
                 match arg {
                     "--overwrite=true" => options.overwrite = true,
@@ -215,7 +244,26 @@ impl std::str::FromStr for Command {
                     }
                 }
             }
-            Ok(Self::PasteFiles(options))
+            Ok(Self::PasteFiles { options })
+        } else if command == CMD_DELETE_FILES {
+            let (mut permanently, mut background) = (false, false);
+            for arg in arg.split_whitespace() {
+                match arg {
+                    "--background=true" => background = true,
+                    "--background=false" => background = false,
+                    "--permanently" => permanently = true,
+                    _ => {
+                        return Err(JoshutoError::new(
+                            JoshutoErrorKind::UnrecognizedArgument,
+                            format!("{}: unknown option '{}'", command, arg),
+                        ))
+                    }
+                }
+            }
+            Ok(Self::DeleteFiles {
+                background,
+                permanently,
+            })
         } else if command == CMD_RENAME_FILE {
             match arg {
                 "" => Err(JoshutoError::new(
@@ -224,7 +272,7 @@ impl std::str::FromStr for Command {
                 )),
                 arg => {
                     let path: path::PathBuf = path::PathBuf::from(arg);
-                    Ok(Self::RenameFile(path))
+                    Ok(Self::RenameFile { new_name: path })
                 }
             }
         } else if command == CMD_SEARCH_STRING {
@@ -233,17 +281,23 @@ impl std::str::FromStr for Command {
                     JoshutoErrorKind::InvalidParameters,
                     format!("{}: Expected 1, got 0", command),
                 )),
-                arg => Ok(Self::SearchString(arg.to_string())),
+                arg => Ok(Self::SearchString {
+                    pattern: arg.to_string(),
+                }),
             }
         } else if command == CMD_SEARCH_INCREMENTAL {
-            Ok(Self::SearchIncremental(arg.to_string()))
+            Ok(Self::SearchIncremental {
+                pattern: arg.to_string(),
+            })
         } else if command == CMD_SEARCH_GLOB {
             match arg {
                 "" => Err(JoshutoError::new(
                     JoshutoErrorKind::InvalidParameters,
                     format!("{}: Expected 1, got 0", command),
                 )),
-                arg => Ok(Self::SearchGlob(arg.to_string())),
+                arg => Ok(Self::SearchGlob {
+                    pattern: arg.to_string(),
+                }),
             }
         } else if command == CMD_SELECT_FILES {
             let mut options = SelectOption::default();
@@ -261,7 +315,10 @@ impl std::str::FromStr for Command {
                             s => pattern = s,
                         }
                     }
-                    Ok(Self::SelectFiles(pattern.to_string(), options))
+                    Ok(Self::SelectFiles {
+                        pattern: pattern.to_string(),
+                        options,
+                    })
                 }
                 Err(e) => Err(JoshutoError::new(
                     JoshutoErrorKind::InvalidParameters,
@@ -270,7 +327,10 @@ impl std::str::FromStr for Command {
             }
         } else if command == CMD_SUBPROCESS_FOREGROUND || command == CMD_SUBPROCESS_BACKGROUND {
             match shell_words::split(arg) {
-                Ok(s) if !s.is_empty() => Ok(Self::SubProcess(s, command == "spawn")),
+                Ok(s) if !s.is_empty() => Ok(Self::SubProcess {
+                    words: s,
+                    spawn: command == "spawn",
+                }),
                 Ok(_) => Err(JoshutoError::new(
                     JoshutoErrorKind::InvalidParameters,
                     format!("{}: No commands given", command),
@@ -283,7 +343,7 @@ impl std::str::FromStr for Command {
         } else if command == CMD_SORT {
             match arg {
                 "reverse" => Ok(Self::SortReverse),
-                arg => match SortType::parse(arg) {
+                arg => match SortType::from_str(arg) {
                     Some(s) => Ok(Self::Sort(s)),
                     None => Err(JoshutoError::new(
                         JoshutoErrorKind::InvalidParameters,
@@ -291,24 +351,28 @@ impl std::str::FromStr for Command {
                     )),
                 },
             }
+        } else if command == CMD_SET_LINEMODE {
+            Ok(Self::SetLineMode(LineMode::from_string(arg)?))
         } else if command == CMD_TAB_SWITCH {
             match arg.parse::<i32>() {
-                Ok(s) => Ok(Self::TabSwitch(s)),
+                Ok(s) => Ok(Self::TabSwitch { offset: s }),
                 Err(e) => Err(JoshutoError::new(
                     JoshutoErrorKind::InvalidParameters,
                     format!("{}: {}", command, e),
                 )),
             }
         } else if command == CMD_TAB_SWITCH_INDEX {
-            match arg.parse::<u32>() {
-                Ok(s) => Ok(Self::TabSwitchIndex(s)),
+            match arg.parse::<usize>() {
+                Ok(s) => Ok(Self::TabSwitchIndex { index: s }),
                 Err(e) => Err(JoshutoError::new(
                     JoshutoErrorKind::InvalidParameters,
                     format!("{}: {}", command, e),
                 )),
             }
         } else if command == CMD_TOUCH_FILE {
-            Ok(Self::TouchFile(arg.to_string()))
+            Ok(Self::TouchFile {
+                file_name: arg.to_string(),
+            })
         } else if command == CMD_SWITCH_LINE_NUMBERS {
             let policy = match arg {
                 "absolute" | "1" => LineNumberStyle::Absolute,
@@ -318,12 +382,25 @@ impl std::str::FromStr for Command {
             Ok(Self::SwitchLineNums(policy))
         } else if command == CMD_FLAT {
             match arg.parse::<usize>() {
-                Ok(i) => Ok(Self::Flat(i + 1)),
+                Ok(i) => Ok(Self::Flat { depth: i }),
                 Err(e) => Err(JoshutoError::new(
                     JoshutoErrorKind::InvalidParameters,
                     format!("{}: {}", command, e),
                 )),
             }
+        } else if command == CMD_NUMBERED_COMMAND {
+            let c = arg.chars().next();
+            match c {
+                Some(c) => Ok(Self::NumberedCommand { initial: c }),
+                None => Err(JoshutoError::new(
+                    JoshutoErrorKind::InvalidParameters,
+                    format!("{}: no starting character given", command),
+                )),
+            }
+        } else if command == CMD_FILTER {
+            Ok(Self::Filter {
+                pattern: arg.to_string(),
+            })
         } else {
             Err(JoshutoError::new(
                 JoshutoErrorKind::UnrecognizedCommand,
