@@ -4,12 +4,14 @@ use crate::context::AppContext;
 use super::{Command, InteractiveExecute};
 
 impl InteractiveExecute for Command {
-    #[allow(clippy::single_match)]
     fn interactive_execute(&self, context: &mut AppContext) {
         match self {
-            Self::SearchIncremental(pattern) => {
+            Self::SearchIncremental { pattern } => {
                 search_string::search_string(context, pattern.as_str(), true)
             }
+            Self::Filter { pattern } => {
+                filter::filter(context, pattern).ok();
+            }
             _ => (),
         }
     }
