@@ -3,18 +3,31 @@ use std::path;
 use crate::context::AppContext;
 use crate::fs::JoshutoMetadata;
 use crate::preview::{preview_dir, preview_file};
+use crate::ui::AppBackend;
 
-pub fn load_preview_path(context: &mut AppContext, p: path::PathBuf, metadata: JoshutoMetadata) {
+use super::preview_file::PreviewFileState;
+
+pub fn load_preview_path(
+    context: &mut AppContext,
+    backend: &mut AppBackend,
+    p: path::PathBuf,
+    metadata: JoshutoMetadata,
+) {
     let preview_options = context.config_ref().preview_options_ref();
-
     if metadata.is_dir() {
-        let need_to_load = context
-            .tab_context_ref()
-            .curr_tab_ref()
-            .history_ref()
+        let tab = context.tab_context_ref().curr_tab_ref();
+        // only load if there doesn't already exist a loading thread and
+        // there isn't an entry in history
+        let need_to_load = tab
+            .history_metadata_ref()
             .get(p.as_path())
-            .map(|e| e.need_update())
-            .unwrap_or(true);
+            .map(|m| m.is_loading())
+            .unwrap_or(true)
+            && tab
+                .history_ref()
+                .get(p.as_path())
+                .map(|e| e.need_update())
+                .unwrap_or(true);
 
         if need_to_load {
             preview_dir::Background::load_preview(context, p);
@@ -22,22 +35,22 @@ pub fn load_preview_path(context: &mut AppContext, p: path::PathBuf, metadata: J
     } else if metadata.len() <= preview_options.max_preview_size {
         let need_to_load = context
             .preview_context_ref()
-            .get_preview_ref(p.as_path())
-            .map(|p| {
-                p.as_ref()
-                    .map(|p| p.modified < metadata.modified())
-                    .unwrap_or(true)
+            .previews_ref()
+            .get(p.as_path())
+            .map(|data| match data {
+                PreviewFileState::Success { data } => data.modified < metadata.modified(),
+                _ => false,
             })
             .unwrap_or(true);
 
         if need_to_load {
-            preview_file::Background::preview_path_with_script(context, p);
+            preview_file::Background::preview_path_with_script(context, backend, p);
         }
     } else {
     }
 }
 
-pub fn load_preview(context: &mut AppContext) {
+pub fn load_preview(context: &mut AppContext, backend: &mut AppBackend) {
     let mut load_list = Vec::with_capacity(2);
 
     let curr_tab = context.tab_context_ref().curr_tab_ref();
@@ -56,6 +69,6 @@ pub fn load_preview(context: &mut AppContext) {
     }
 
     for (path, metadata) in load_list {
-        load_preview_path(context, path, metadata);
+        load_preview_path(context, backend, path, metadata);
     }
 }
