@@ -6,14 +6,70 @@ use tui::text::Span;
 use tui::widgets::{Block, Borders, Paragraph, Widget, Wrap};
 
 use crate::context::AppContext;
+use crate::preview::preview_dir::PreviewDirState;
+use crate::preview::preview_file::PreviewFileState;
 use crate::ui;
 use crate::ui::widgets::{
-    TuiDirList, TuiDirListDetailed, TuiDirListLoading, TuiFilePreview, TuiFooter, TuiTabBar,
-    TuiTopBar,
+    TuiDirList, TuiDirListDetailed, TuiDirListLoading, TuiFilePreview, TuiFooter, TuiMessage,
+    TuiTabBar, TuiTopBar,
 };
 use crate::ui::PreviewArea;
 
-const TAB_VIEW_WIDTH: u16 = 15;
+struct TuiFolderViewBorders<'a> {
+    pub constraints: &'a [Constraint; 3],
+}
+
+impl<'a> TuiFolderViewBorders<'a> {
+    pub fn new(constraints: &'a [Constraint; 3]) -> Self {
+        Self { constraints }
+    }
+}
+
+impl<'a> Widget for TuiFolderViewBorders<'a> {
+    fn render(self, area: Rect, buf: &mut Buffer) {
+        let block = Block::default().borders(Borders::ALL);
+        let inner = block.inner(area);
+        block.render(area, buf);
+
+        let layout_rect = Layout::default()
+            .direction(Direction::Horizontal)
+            .constraints(self.constraints.as_ref())
+            .split(inner);
+
+        // Won't render intersections if parent view is turned off
+        match self.constraints[0] {
+            Constraint::Ratio(0, _) => {}
+            _ => {
+                let block = Block::default().borders(Borders::RIGHT);
+                block.render(layout_rect[0], buf);
+            }
+        }
+        let block = Block::default().borders(Borders::LEFT);
+        block.render(layout_rect[2], buf);
+
+        let top = area.top();
+        let bottom = area.bottom() - 1;
+        let left = layout_rect[1].left() - 1;
+        let right = layout_rect[2].left();
+        let intersections = Intersections {
+            top,
+            bottom,
+            left,
+            right,
+        };
+
+        // Won't render intersections if parent view is turned off
+        match self.constraints[0] {
+            Constraint::Ratio(0, _) => (),
+            _ => intersections.render_left(buf),
+        }
+        // Won't render intersections if child preview is unavailable
+        match self.constraints[2] {
+            Constraint::Ratio(0, _) => (),
+            _ => intersections.render_right(buf),
+        }
+    }
+}
 
 pub struct TuiFolderView<'a> {
     pub context: &'a AppContext,
@@ -27,83 +83,81 @@ impl<'a> TuiFolderView<'a> {
             show_bottom_status: true,
         }
     }
+
+    pub fn folder_area(area: &Rect) -> Rect {
+        Rect {
+            y: area.top() + 1,
+            height: area.bottom() - 2,
+            ..*area
+        }
+    }
+
+    pub fn header_area(area: &Rect) -> Rect {
+        Rect {
+            x: area.left(),
+            y: area.top(),
+            width: area.width,
+            height: 1,
+        }
+    }
+
+    pub fn footer_area(area: &Rect) -> Rect {
+        Rect {
+            x: area.x,
+            y: area.bottom() - 1,
+            width: area.width,
+            height: 1,
+        }
+    }
+
+    pub fn tab_area(&self, area: &Rect, num_tabs: usize) -> Rect {
+        // render tabs
+        let tab_width = (num_tabs * 8) as u16;
+        let tab_width = if tab_width > area.width {
+            area.width
+        } else {
+            tab_width
+        };
+        let topbar_x = area.width.saturating_sub(tab_width);
+
+        Rect {
+            x: topbar_x,
+            y: area.top(),
+            width: tab_width,
+            height: 1,
+        }
+    }
 }
 
 impl<'a> Widget for TuiFolderView<'a> {
     fn render(self, area: Rect, buf: &mut Buffer) {
+        let config = self.context.config_ref();
+        let display_options = config.display_options_ref();
+
         let preview_context = self.context.preview_context_ref();
         let curr_tab = self.context.tab_context_ref().curr_tab_ref();
+        let curr_tab_cwd = curr_tab.cwd();
 
         let curr_list = curr_tab.curr_list_ref();
         let child_list = curr_tab.child_list_ref();
 
         let curr_entry = curr_list.and_then(|c| c.curr_entry_ref());
 
-        let config = self.context.config_ref();
-        let display_options = config.display_options_ref();
-
         let constraints = get_constraints(self.context);
-        let is_default_layout = constraints == &display_options.default_layout;
 
         let layout_rect = if display_options.show_borders() {
-            let area = Rect {
-                y: area.top() + 1,
-                height: area.height - 2,
-                ..area
-            };
+            let area = Self::folder_area(&area);
+            TuiFolderViewBorders::new(constraints).render(area, buf);
 
-            let layout = calculate_layout_with_borders(area, constraints);
-
-            let block = Block::default().borders(Borders::ALL);
-            let inner = block.inner(area);
-            block.render(area, buf);
-
-            let layout_rect = Layout::default()
-                .direction(Direction::Horizontal)
-                .constraints(constraints.as_ref())
-                .split(inner);
-
-            let block = Block::default().borders(Borders::RIGHT);
-            block.render(layout_rect[0], buf);
-
-            let block = Block::default().borders(Borders::LEFT);
-            block.render(layout_rect[2], buf);
-
-            // Render inner borders properly.
-            {
-                let top = area.top();
-                let bottom = area.bottom() - 1;
-                let left = layout_rect[1].left() - 1;
-                let right = layout_rect[2].left();
-                let intersections = Intersections {
-                    top,
-                    bottom,
-                    left,
-                    right,
-                };
-
-                // Won't render intersections if parent view is turned off
-                match constraints[0] {
-                    Constraint::Ratio(0, _) => (),
-                    _ => intersections.render_left(buf),
-                }
-                if is_default_layout {
-                    intersections.render_right(buf);
-                }
-            }
-            layout
+            calculate_layout_with_borders(area, constraints)
         } else {
-            let area = Rect {
-                y: area.top() + 1,
-                height: area.height - 2,
-                ..area
-            };
+            let area = Self::folder_area(&area);
             calculate_layout(area, constraints)
         };
 
         // render parent view
         match constraints[0] {
-            Constraint::Ratio(0, _) => (),
+            Constraint::Ratio(0, _) => {}
             _ => {
                 if let Some(list) = curr_tab.parent_list_ref().as_ref() {
                     TuiDirList::new(list, true).render(layout_rect[0], buf);
@@ -113,14 +167,10 @@ impl<'a> Widget for TuiFolderView<'a> {
 
         // render current view
         if let Some(list) = curr_list.as_ref() {
-            TuiDirListDetailed::new(list, display_options, true).render(layout_rect[1], buf);
-            let rect = Rect {
-                x: 0,
-                y: area.height - 1,
-                width: area.width,
-                height: 1,
-            };
+            TuiDirListDetailed::new(list, display_options, curr_tab.option_ref(), true)
+                .render(layout_rect[1], buf);
 
+            let footer_area = Self::footer_area(&area);
             if self.show_bottom_status {
                 /* draw the bottom status bar */
                 if let Some(msg) = self.context.worker_context_ref().get_msg() {
@@ -128,70 +178,69 @@ impl<'a> Widget for TuiFolderView<'a> {
                     let text = Span::styled(msg, message_style);
                     Paragraph::new(text)
                         .wrap(Wrap { trim: true })
-                        .render(rect, buf);
+                        .render(footer_area, buf);
                 } else if let Some(msg) = self.context.message_queue_ref().current_message() {
                     let text = Span::styled(msg.content.as_str(), msg.style);
                     Paragraph::new(text)
                         .wrap(Wrap { trim: true })
-                        .render(rect, buf);
+                        .render(footer_area, buf);
                 } else {
-                    TuiFooter::new(list).render(rect, buf);
+                    TuiFooter::new(list, curr_tab.option_ref()).render(footer_area, buf);
                 }
             }
+        } else {
+            match curr_tab.history_metadata_ref().get(curr_tab_cwd) {
+                Some(PreviewDirState::Loading) => {
+                    TuiDirListLoading::new().render(layout_rect[1], buf);
+                }
+                Some(PreviewDirState::Error { message }) => {
+                    TuiMessage::new(message, Style::default().fg(Color::Red))
+                        .render(layout_rect[1], buf);
+                }
+                None => {}
+            }
         }
 
         if let Some(list) = child_list.as_ref() {
             TuiDirList::new(list, true).render(layout_rect[2], buf);
-        } else if curr_entry.is_some() {
-            let preview_area = calculate_preview(self.context, layout_rect[2]);
-            if let Some(preview_area) = preview_area {
-                let area = Rect {
-                    x: preview_area.preview_area.x,
-                    y: preview_area.preview_area.y,
-                    width: preview_area.preview_area.width,
-                    height: preview_area.preview_area.height,
-                };
-                if let Some(Some(preview)) =
-                    preview_context.get_preview_ref(&preview_area.file_preview_path)
-                {
-                    TuiFilePreview::new(preview).render(area, buf);
+        } else if let Some(entry) = curr_entry {
+            match curr_tab.history_metadata_ref().get(entry.file_path()) {
+                Some(PreviewDirState::Loading) => {
+                    TuiDirListLoading::new().render(layout_rect[2], buf);
+                }
+                Some(PreviewDirState::Error { message }) => {
+                    TuiMessage::new(message, Style::default().fg(Color::Red))
+                        .render(layout_rect[2], buf);
+                }
+                None => {
+                    let preview_area = calculate_preview(self.context, layout_rect[2]);
+                    if let Some(preview_area) = preview_area {
+                        let area = Rect {
+                            x: preview_area.preview_area.x,
+                            y: preview_area.preview_area.y,
+                            width: preview_area.preview_area.width,
+                            height: preview_area.preview_area.height,
+                        };
+                        if let Some(PreviewFileState::Success { data }) = preview_context
+                            .previews_ref()
+                            .get(&preview_area.file_preview_path)
+                        {
+                            TuiFilePreview::new(data).render(area, buf);
+                        }
+                    }
                 }
             }
         } else {
-            TuiDirListLoading::new().render(layout_rect[2], buf);
+            TuiMessage::new("Error loading directory", Style::default().fg(Color::Red))
+                .render(layout_rect[2], buf);
         }
 
-        let topbar_width = area.width;
-        let rect = Rect {
-            x: 0,
-            y: 0,
-            width: topbar_width,
-            height: 1,
-        };
-        TuiTopBar::new(self.context, curr_tab.cwd()).render(rect, buf);
+        let topbar_area = Self::header_area(&area);
+        TuiTopBar::new(self.context, curr_tab_cwd).render(topbar_area, buf);
 
         // render tabs
-        if self.context.tab_context_ref().len() > 1 {
-            let topbar_width = area.width.saturating_sub(TAB_VIEW_WIDTH);
-
-            let rect = Rect {
-                x: topbar_width,
-                y: 0,
-                width: TAB_VIEW_WIDTH,
-                height: 1,
-            };
-            let name = if let Some(ostr) = curr_tab.cwd().file_name() {
-                ostr.to_str().unwrap_or("")
-            } else {
-                ""
-            };
-            TuiTabBar::new(
-                name,
-                self.context.tab_context_ref().index,
-                self.context.tab_context_ref().len(),
-            )
-            .render(rect, buf);
-        }
+        let tab_area = self.tab_area(&area, self.context.tab_context_ref().len());
+        TuiTabBar::new(self.context.tab_context_ref()).render(tab_area, buf);
     }
 }
 
@@ -240,8 +289,11 @@ pub fn get_constraints(context: &AppContext) -> &[Constraint; 3] {
                 Some(entry) if entry.metadata.file_type().is_dir() => {
                     &display_options.default_layout
                 }
-                Some(entry) => match preview_context.get_preview_ref(entry.file_path()) {
-                    Some(Some(p)) if p.status.code() != Some(1) => &display_options.default_layout,
+                Some(entry) => match preview_context.previews_ref().get(entry.file_path()) {
+                    Some(PreviewFileState::Success { data }) if data.status.code() != Some(1) => {
+                        &display_options.default_layout
+                    }
+                    Some(PreviewFileState::Loading) => &display_options.default_layout,
                     _ => &display_options.no_preview_layout,
                 },
             },
@@ -253,7 +305,8 @@ pub fn calculate_layout(area: Rect, constraints: &[Constraint; 3]) -> Vec<Rect>
     let mut layout_rect = Layout::default()
         .direction(Direction::Horizontal)
         .constraints(constraints.as_ref())
-        .split(area);
+        .split(area)
+        .to_vec();
 
     layout_rect[0] = Rect {
         width: layout_rect[0].width - 1,
@@ -296,8 +349,10 @@ pub fn calculate_preview(context: &AppContext, rect: Rect) -> Option<PreviewArea
     if child_list.as_ref().is_some() {
         None
     } else if let Some(entry) = curr_entry {
-        if let Some(Some(preview)) = preview_context.get_preview_ref(entry.file_path()) {
-            match preview.status.code() {
+        if let Some(PreviewFileState::Success { data }) =
+            preview_context.previews_ref().get(entry.file_path())
+        {
+            match data.status.code() {
                 Some(1) | None => None,
                 _ => {
                     let file_preview_path = entry.file_path_buf();
