@@ -5,6 +5,7 @@ mod tui_file_preview;
 mod tui_footer;
 mod tui_help;
 mod tui_menu;
+mod tui_message;
 mod tui_prompt;
 mod tui_tab;
 mod tui_text;
@@ -18,6 +19,7 @@ pub use self::tui_file_preview::TuiFilePreview;
 pub use self::tui_footer::TuiFooter;
 pub use self::tui_help::{get_keymap_table, TuiHelp};
 pub use self::tui_menu::TuiMenu;
+pub use self::tui_message::TuiMessage;
 pub use self::tui_prompt::TuiPrompt;
 pub use self::tui_tab::TuiTabBar;
 pub use self::tui_text::TuiMultilineText;
