@@ -1,12 +1,10 @@
-#[cfg(feature = "devicons")]
-pub mod devicons;
-
 pub mod format;
+pub mod fs;
 pub mod keyparse;
+pub mod mimetype;
 pub mod name_resolution;
 pub mod process;
 pub mod search;
 pub mod string;
 pub mod style;
-pub mod to_string;
 pub mod unix;
