@@ -1,4 +1,7 @@
+use std::path;
+
 pub fn is_executable(mode: u32) -> bool {
+    #[allow(clippy::unnecessary_cast)]
     const LIBC_PERMISSION_VALS: [u32; 3] = [
         libc::S_IXUSR as u32,
         libc::S_IXGRP as u32,
@@ -9,6 +12,7 @@ pub fn is_executable(mode: u32) -> bool {
 }
 
 pub fn mode_to_string(mode: u32) -> String {
+    #[allow(clippy::unnecessary_cast)]
     const LIBC_FILE_VALS: [(u32, char); 7] = [
         (libc::S_IFREG as u32 >> 9, '-'),
         (libc::S_IFDIR as u32 >> 9, 'd'),
@@ -19,6 +23,7 @@ pub fn mode_to_string(mode: u32) -> String {
         (libc::S_IFIFO as u32 >> 9, 'f'),
     ];
 
+    #[allow(clippy::unnecessary_cast)]
     const LIBC_PERMISSION_VALS: [(u32, char); 9] = [
         (libc::S_IRUSR as u32, 'r'),
         (libc::S_IWUSR as u32, 'w'),
@@ -50,3 +55,15 @@ pub fn mode_to_string(mode: u32) -> String {
     }
     mode_str
 }
+
+pub fn expand_shell_string(s: &str) -> path::PathBuf {
+    let dir = dirs_next::home_dir();
+    let os_str = dir.map(|s| s.as_os_str().to_owned());
+    let context_func = || {
+        let cow_str = os_str.as_ref().map(|s| s.to_string_lossy());
+        cow_str
+    };
+    let tilde_cow = shellexpand::tilde_with_context(s, context_func);
+    let tilde_path = path::PathBuf::from(tilde_cow.as_ref());
+    tilde_path
+}
